@@ -2,24 +2,36 @@
 
 import calendar
 
+from dataclasses import dataclass
 from datetime import date as _date
 from datetime import datetime as _datetime
 from typing import Iterator
 from typing import Optional
-from typing import Union
 
 
 try:  # Python <3.9
-    from zoneinfo import ZoneInfo
+    from zoneinfo import ZoneInfo  # type: ignore
 except ImportError:
-    from backports import zoneinfo as ZoneInfo  # type: ignore
+    from backports.zoneinfo import ZoneInfo  # type: ignore
 
 from dateutil import parser
-from dateutil.relativedelta import relativedelta
-from timeless import utils
+from dateutil import relativedelta
 
 
-class Datetime(_datetime, _date):
+@dataclass
+class Weekdays:
+    """Weekdays mapping for easy acess."""
+
+    monday = relativedelta.MO
+    tuesday = relativedelta.TU
+    wednesday = relativedelta.WE
+    thursday = relativedelta.TH
+    friday = relativedelta.FR
+    saturday = relativedelta.SA
+    sunday = relativedelta.SU
+
+
+class Datetime(_datetime):
     """Timeless datetime."""
 
     def __new__(
@@ -31,12 +43,9 @@ class Datetime(_datetime, _date):
         minute: int = 0,
         second: int = 0,
         microsecond: int = 0,
-        zone: Union[ZoneInfo, str] = ZoneInfo("UTC"),
+        zone: str = "UTC",
     ) -> "Datetime":
         """Control the instance creation."""
-        if isinstance(zone, str):
-            zone = ZoneInfo(zone)
-
         self = _datetime.__new__(
             cls,
             year=year,
@@ -46,8 +55,9 @@ class Datetime(_datetime, _date):
             minute=minute,
             second=second,
             microsecond=microsecond,
-            tzinfo=zone,
+            tzinfo=ZoneInfo(zone),
         )
+
         return self
 
     def add(
@@ -68,7 +78,7 @@ class Datetime(_datetime, _date):
         Datetime
             New datetime instance with added value.
         """
-        dt = self + relativedelta(
+        dt = self + relativedelta.relativedelta(
             years=years,
             months=months,
             days=days,
@@ -79,13 +89,13 @@ class Datetime(_datetime, _date):
         )
 
         return self.__class__(
-            year=dt.year,
-            month=dt.month,
-            day=dt.day,
-            hour=dt.hour,
-            minute=dt.minute,
-            second=dt.second,
-            microsecond=dt.microsecond,
+            dt.year,
+            dt.month,
+            dt.day,
+            dt.hour,
+            dt.minute,
+            dt.second,
+            dt.microsecond,
             zone=self.zone,
         )
 
@@ -107,7 +117,7 @@ class Datetime(_datetime, _date):
         Datetime
             New datetime instance with the subtracted value.
         """
-        dt = self - relativedelta(
+        dt = self - relativedelta.relativedelta(
             years=years,
             months=months,
             days=days,
@@ -116,14 +126,15 @@ class Datetime(_datetime, _date):
             seconds=seconds,
             microseconds=microseconds,
         )
+
         return self.__class__(
-            year=dt.year,
-            month=dt.month,
-            day=dt.day,
-            hour=dt.hour,
-            minute=dt.minute,
-            second=dt.second,
-            microsecond=dt.microsecond,
+            dt.year,
+            dt.month,
+            dt.day,
+            dt.hour,
+            dt.minute,
+            dt.second,
+            dt.microsecond,
             zone=self.zone,
         )
 
@@ -157,7 +168,7 @@ class Datetime(_datetime, _date):
         minute: Optional[int] = None,
         second: Optional[int] = None,
         microsecond: Optional[int] = None,
-        zone: Optional[Union[str, ZoneInfo]] = "UTC",
+        zone: Optional[str] = "UTC",
     ) -> "Datetime":
         """
         Override the instance values.
@@ -179,7 +190,7 @@ class Datetime(_datetime, _date):
         microsecond : Optional[int], optional
             new microsecond value, by default None
         zone : Optional[Union[str, ZoneInfo]], optional
-            new timezone value, by default "UTC"
+            new timezone value
 
         Returns
         -------
@@ -205,24 +216,24 @@ class Datetime(_datetime, _date):
             # we can safely assume that timezone is always set
             zone = str(self.tzinfo)
 
-        return self.__class__(
-            year, month, day, hour, minute, second, microsecond, zone=zone
+        return self.__new__(
+            self.__class__,
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            second,
+            microsecond,
+            zone=zone,
         )
 
+    def utc(self) -> "Datetime":
+        """Set datetime as UTC without apply the timezone offset."""
+        return self.set(zone="UTC")
+
     @property
     def zone(self) -> str:
-        """
-        Get the timezone name.
-
-        Returns
-        -------
-        str
-            Timezone name.
-        """
-        return str(self.tzinfo)
-
-    @property
-    def zone_info(self) -> ZoneInfo:
         """
         Get the timezone object.
 
@@ -231,7 +242,7 @@ class Datetime(_datetime, _date):
         ZoneInfo
             Timezone object.
         """
-        return ZoneInfo(self.zone)
+        return str(self.tzinfo)
 
     def is_future(self) -> bool:
         """
@@ -274,16 +285,11 @@ class Datetime(_datetime, _date):
 
         return self.strftime(format)
 
-    @property
-    def zero(self) -> "Datetime":
-        """Get rid of hour, minute, second, and microsecond information."""
-        return self.set(hour=0, minute=0, second=0, microsecond=0, zone=self.zone)
-
     def set_zero(self) -> "Datetime":
-        """Equivalent function of zero property."""
-        return self.zero
+        """Get rid of hour, minute, second, microsecond and timezone information."""
+        return self.set(hour=0, minute=0, second=0, microsecond=0, zone="UTC")
 
-    def diff(self, other: "Datetime") -> relativedelta:
+    def diff(self, other: "Datetime") -> relativedelta.relativedelta:
         """
         Get the difference between the instance and another.
 
@@ -297,7 +303,7 @@ class Datetime(_datetime, _date):
         relativedelta
             Delta between the two instances.
         """
-        return relativedelta(self, other)
+        return relativedelta.relativedelta(self, other)
 
     def get_next(self, weekday: str) -> "Datetime":
         """
@@ -310,8 +316,8 @@ class Datetime(_datetime, _date):
         Datetime
             Next closest given weekday.
         """
-        weekday_ = utils.Weekdays.__dict__[weekday]
-        next_weekday = self + relativedelta(days=1, weekday=weekday_)
+        weekday_ = Weekdays.__dict__[weekday]
+        next_weekday = self + relativedelta.relativedelta(days=1, weekday=weekday_)
 
         return self.__class__(
             next_weekday.year,
@@ -333,8 +339,8 @@ class Datetime(_datetime, _date):
         Datetime
             Last closest given weekday.
         """
-        weekday_ = utils.Weekdays.__dict__[weekday](-1)
-        next_weekday = self + relativedelta(days=-1, weekday=weekday_)
+        weekday_ = Weekdays.__dict__[weekday](-1)
+        next_weekday = self + relativedelta.relativedelta(days=-1, weekday=weekday_)
 
         return self.__class__(
             next_weekday.year,
@@ -362,7 +368,7 @@ class Datetime(_datetime, _date):
             [description]
         """
         if week_start:
-            calendar.setfirstweekday(utils.Weekdays.__dict__[week_start])
+            calendar.setfirstweekday(Weekdays.__dict__[week_start])
 
         numeric_weekday = self.weekday()
         weekday_name = calendar.day_name[numeric_weekday]
@@ -414,8 +420,50 @@ class Datetime(_datetime, _date):
         """
         return self.days_in_month
 
+    def get_month_start(self) -> "Datetime":
+        """
+        Get a Datetime instance on the first day of the month.
 
-def now(zone: str = "UTC") -> Datetime:
+        Only for semantic purposes.
+
+        Returns
+        -------
+        Datetime
+            First day of the month
+        """
+        return self.__class__(
+            self.year,
+            self.month,
+            1,
+            self.hour,
+            self.minute,
+            self.second,
+            self.microsecond,
+            zone=self.zone,
+        )
+
+    def get_month_end(self) -> "Datetime":
+        """
+        Get a Datetime instance on the last day of the month.
+
+        Returns
+        -------
+        Datetime
+            Kast day of the month
+        """
+        return self.__class__(
+            self.year,
+            self.month,
+            self.days_in_month,
+            self.hour,
+            self.minute,
+            self.second,
+            self.microsecond,
+            zone=self.zone,
+        )
+
+
+def now(zone: str = "UTC", microseconds: bool = False) -> Datetime:
     """
     Get a DateTime instance for the current date and time.
 
@@ -430,6 +478,12 @@ def now(zone: str = "UTC") -> Datetime:
         Current date and time.
     """
     dt_ = _datetime.now(tz=ZoneInfo(zone))
+
+    if microseconds:
+        ms = dt_.microsecond
+    else:
+        ms = 0
+
     dt = Datetime(
         dt_.year,
         dt_.month,
@@ -437,7 +491,7 @@ def now(zone: str = "UTC") -> Datetime:
         dt_.hour,
         dt_.minute,
         dt_.second,
-        dt_.microsecond,
+        ms,
         zone,
     )
 
